==> kdeadmin-1.91.tar.bz2: kdeadmin-1.91/kpackage/packageProperties.h <==
/////////////////////////////////////////////////////////////////////////////
//      $Id: packageProperties.h,v 1.10 2000/03/05 11:42:58 toivo Exp $ 
// File  : packageProperties.h
// Author: Damyan Pepper
// Author: Toivo Pedaste
//
// This widget is used to provide a list of all the properties that are
// found in the package's property dictionary
//
/////////////////////////////////////////////////////////////////////////////

#ifndef PACKAGEPROPERTIES_H
#define PACKAGEPROPERTIES_H
#include "../config.h"

// Standard Headers

// Qt Headers
#include <qtablevw.h>
#include <qpainter.h>
#include <qstringlist.h> 
#include <qregexp.h> 
#include <qtextbrowser.h> 

// KDE Headers
#include <klocale.h>

// kpackage Headers
#include "packageInfo.h"

class packageInfo;

class packagePropertiesWidget : public QTextBrowser
{
  Q_OBJECT;
  ///////////// METHODS ------------------------------------------------------
public:

  packagePropertiesWidget(QWidget *parent=0, const char *name=0);
  // constructor

  ~packagePropertiesWidget();
  // destructor

  void changePackage(packageInfo *p);

  void setSource( const QString & name );
  // url selected

protected:



  ///////////// DATA ---------------------------------------------------------
private:
  packageInfo *package;
 
  void initTranslate();
  void iList(QString txt, QString itxt);

  QDict<QString> trl ;
  // allow for translation of labels

  QStringList pList;
  // list specifying order of property distplay

  QStringList cList;
  // list giving order of currently displayed properties

  QString stmp;
  // text accumulation buffer

  void depends(QString f);
  // translate depends string

  void dor(QString f);
  // translate depends string

  void delement(QString f);
  // translate depends element
};


#endif

==> kdeadmin-3.0.1.tar.bz2: kdeadmin-3.0.1/kpackage/packageProperties.h <==
/////////////////////////////////////////////////////////////////////////////
//      $Id: packageProperties.h,v 1.12 2001/09/02 20:30:08 bruggie Exp $ 
// File  : packageProperties.h
// Author: Damyan Pepper
// Author: Toivo Pedaste
//
// This widget is used to provide a list of all the properties that are
// found in the package's property dictionary
//
/////////////////////////////////////////////////////////////////////////////

#ifndef PACKAGEPROPERTIES_H
#define PACKAGEPROPERTIES_H
#include "../config.h"

// Standard Headers

// Qt Headers
#include <qttableview.h>
#include <qpainter.h>
#include <qstringlist.h> 
#include <qregexp.h> 
#include <qtextbrowser.h> 

// KDE Headers
#include <klocale.h>

// kpackage Headers
#include "packageInfo.h"

class packageInfo;

class packagePropertiesWidget : public QTextBrowser
{
  Q_OBJECT;
  ///////////// METHODS ------------------------------------------------------
public:

  packagePropertiesWidget(QWidget *parent=0);
  // constructor

  ~packagePropertiesWidget();
  // destructor

  void changePackage(packageInfo *p);

  void setSource( const QString & name );
  // url selected

protected:



  ///////////// DATA ---------------------------------------------------------
private:
  packageInfo *package;
 
  void initTranslate();
  void iList(QString txt, QString itxt);

  QDict<QString> trl ;
  // allow for translation of labels

  QStringList pList;
  // list specifying order of property distplay

  QStringList cList;
  // list giving order of currently displayed properties

  QString stmp;
  // text accumulation buffer

  void depends(QString f);
  // translate depends string

  void dor(QString f);
  // translate depends string

  void delement(QString f);
  // translate depends element
};


#endif
